﻿using Ozeki.Media;
using Ozeki.VoIP;
using System;

namespace Google_Text_To_Speech
{
    class Program
    {
        static ISoftPhone _softphone;   // softphone object
        static IPhoneLine _phoneLine;   // phoneline object
        static IPhoneCall _call;
        static MediaConnector _connector;

        static GoogleTTS googleAPI;
        static PhoneCallAudioSender _mediaSender;

        static void Main(string[] args)
        {
            _softphone = SoftPhoneFactory.CreateSoftPhone(5000, 10000);

            //   SIP account registration data, (supplied by your VoIP service provider)
            var registrationRequired = true;
            var userName = "112";
            var displayName = "112";
            var authenticationId = "112";
            var registerPassword = "112";
            var domainHost = "192.168.115.60";
            var domainPort = 5060;

            var account = new SIPAccount(registrationRequired, displayName, userName, authenticationId, registerPassword, domainHost, domainPort);
            
            _mediaSender = new PhoneCallAudioSender();
            _connector = new MediaConnector();
        
            RegisterAccount(account);

            Console.ReadLine();
        }

        static void RegisterAccount(SIPAccount account)
        {
            try
            {
                _phoneLine = _softphone.CreatePhoneLine(account);
                _phoneLine.RegistrationStateChanged += line_RegStateChanged;
                _softphone.RegisterPhoneLine(_phoneLine);
            }
            catch (Exception ex)
            {
                Console.WriteLine("Error during SIP registration: " + ex);
            }
        }

        static void line_RegStateChanged(object sender, RegistrationStateChangedArgs e)
        {
            if (e.State == RegState.NotRegistered || e.State == RegState.Error)
                Console.WriteLine("Registration failed!");

            if (e.State == RegState.RegistrationSucceeded)
            {
                Console.WriteLine("Registration succeeded - Online!");
                CreateCall();
            }
        }

        private static void CreateCall()
        {
            var numberToDial = "100";
            _call = _softphone.CreateCallObject(_phoneLine, numberToDial);
            _call.CallStateChanged += call_CallStateChanged;
            _call.Start();
        }
        
        static void SetupTextToSpeech()
        {
            googleAPI = new GoogleTTS(GoogleLanguage.English_United_Kingdom);
            
            _mediaSender.AttachToCall(_call);
            _connector.Connect(googleAPI, _mediaSender);

            googleAPI.AddAndStartText("Test message from google text to speech api through voip call.");
        }

        static void call_CallStateChanged(object sender, CallStateChangedArgs e)
        {
            Console.WriteLine("Call state: {0}.", e.State);

            if (e.State == CallState.Answered)
                SetupTextToSpeech();
        }
    }
}